@@ -9,8 +9,36 @@ compas.geometry
 Functions
 =========
 
-Basic
------
+The functions in this section take various geometric primitives as input parameters.
+These primitives may be passed into those functions as instances of the
+corresponding classes or as an equivalent representation using (combinations of)
+built-in Python objects. The following table defines those equivalent representations.
+
+.. rst-class:: table table-responsive table-bordered
+
+=========== ====================================================================
+parameter   representation
+=========== ====================================================================
+vector      list of XYZ coordinates.
+point       list of XYZ coordinates.
+segment     2-tuple of points.
+line        2-tuple of points.
+ray         2-tuple of points.
+polyline    list of points.
+polygon     list of points.
+plane       2-tuple of origin (point) and normal (vector).
+frame       3-tuple of origin (point), U axis (vector) and V axis (vector).
+circle      3-tuple of center (point), normal (vector) and radius (float).
+=========== ====================================================================
+
+.. note::
+
+    Many functions have a `_xy` variant. These variants ignore the Z-component of
+    the input parameters and return a result in the XY plane (with `z = 0`).
+
+
+Linalg
+------
 
 .. autosummary::
     :toctree: generated/
@@ -54,32 +82,7 @@ Basic
     vector_component
     vector_component_xy
 
-Distance
---------
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    closest_point_in_cloud
-    closest_point_in_cloud_xy
-    closest_point_on_line
-    closest_point_on_line_xy
-    closest_point_on_plane
-    closest_point_on_polyline
-    closest_point_on_polyline_xy
-    closest_point_on_segment
-    closest_point_on_segment_xy
-    distance_line_line
-    distance_point_line
-    distance_point_line_xy
-    distance_point_line_sqrd
-    distance_point_line_sqrd_xy
-    distance_point_plane
-    distance_point_point
-    distance_point_point_xy
-    distance_point_point_sqrd
-    distance_point_point_sqrd_xy
+-------
 
 Angles
 ------
@@ -119,6 +122,103 @@ Average
     midpoint_line_xy
     weighted_centroid_points
 
+Bounding Box
+------------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    bbox
+    bbox_numpy
+
+Bestfit
+-------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    bestfit_circle_numpy
+    bestfit_plane
+    bestfit_plane_numpy
+
+Convex Hull
+-----------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    convex_hull
+    convex_hull_numpy
+    convex_hull_xy
+    convex_hull_xy_numpy
+
+Distance
+--------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    closest_point_in_cloud
+    closest_point_in_cloud_xy
+    closest_point_on_line
+    closest_point_on_line_xy
+    closest_point_on_plane
+    closest_point_on_polyline
+    closest_point_on_polyline_xy
+    closest_point_on_segment
+    closest_point_on_segment_xy
+    distance_line_line
+    distance_point_line
+    distance_point_line_xy
+    distance_point_line_sqrd
+    distance_point_line_sqrd_xy
+    distance_point_plane
+    distance_point_point
+    distance_point_point_xy
+    distance_point_point_sqrd
+    distance_point_point_sqrd_xy
+
+Interpolation
+-------------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    discrete_coons_patch
+    tween_points
+    tween_points_distance
+
+Intersections
+-------------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    intersection_circle_circle_xy
+    intersection_line_line
+    intersection_line_line_xy
+    intersection_line_plane
+    intersection_line_triangle
+    intersection_plane_plane
+    intersection_plane_plane_plane
+    intersection_segment_segment_xy
+    intersection_segment_plane
+
+Isolines
+--------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    scalarfield_contours_numpy
+
 Normals
 -------
 
@@ -130,6 +230,27 @@ Normals
     normal_triangle
     normal_triangle_xy
 
+Offset
+------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    offset_line
+    offset_polyline
+    offset_polygon
+
+Planarisation
+-------------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    flatness
+    planarize_faces
+
 Queries
 -------
 
@@ -165,23 +286,6 @@ Queries
     is_point_in_triangle
     is_point_in_triangle_xy
 
-Intersections
--------------
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    intersection_circle_circle_xy
-    intersection_line_line
-    intersection_line_line_xy
-    intersection_line_plane
-    intersection_line_triangle
-    intersection_plane_plane
-    intersection_plane_plane_plane
-    intersection_segment_segment_xy
-    intersection_segment_plane
-
 Size
 ----
 
@@ -195,6 +299,17 @@ Size
     area_triangle_xy
     volume_polyhedron
 
+Smoothing
+---------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    smooth_centroid
+    smooth_centerofmass
+    smooth_area
+
 Transformations
 ---------------
 
@@ -202,8 +317,6 @@ Transformations
     :toctree: generated/
     :nosignatures:
 
-    mesh_transform
-    mesh_transformed
     mirror_points_line
     mirror_points_line_xy
     mirror_points_plane
@@ -220,10 +333,25 @@ Transformations
     translate_points
     translate_points_xy
 
+Triangulation
+-------------
 
-Objects
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    delaunay_from_points
+    delaunay_from_points_numpy
+    voronoi_from_points_numpy
+    voronoi_from_delaunay
+
+
+Classes
 =======
 
+Primitives
+----------
+
 .. autosummary::
     :toctree: generated/
     :nosignatures:
@@ -237,9 +365,8 @@ Objects
     Frame
     Circle
 
-
 XForms
-======
+------
 
 .. autosummary::
     :toctree: generated/
@@ -253,9 +380,8 @@ XForms
     Projection
     Shear
 
-
-Spatial
-=======
+Other
+-----
 
 .. autosummary::
     :toctree: generated/
@@ -264,41 +390,6 @@ Spatial
     KDTree
 
 
-Algorithms
-==========
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    bestfit_plane
-    bounding_box
-    bounding_box_xy
-    convex_hull
-    convex_hull_xy
-    convex_hull_numpy
-    convex_hull_xy_numpy
-    discrete_coons_patch
-    flatness
-    mesh_contours_numpy
-    mesh_cull_duplicate_vertices
-    mesh_flatness
-    mesh_isolines_numpy
-    mesh_planarize_faces
-    mesh_smooth_centroid
-    network_parallelise_edges
-    network_smooth_centroid
-    offset_line
-    offset_polyline
-    offset_polygon
-    oriented_bounding_box_numpy
-    oriented_bounding_box_xy_numpy
-    planarize_faces
-    scalarfield_contours_numpy
-    smooth_area
-    smooth_centroid
-    smooth_centerofmass
-
 """
 from __future__ import absolute_import
 from __future__ import division
@@ -315,11 +406,19 @@ from .size import *
 
 from .transformations import *
 
-from .objects import *
+from .bbox import *
+from .bestfit import *
+from .hull import *
+from .interpolation import *
+from .isolines import *
+from .offset import *
+from .planarisation import *
+from .smoothing import *
 from .spatial import *
-from .xforms import *
+from .triangulation import *
 
-from .algorithms import *
+from ._primitives import *
+from .xforms import *
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
