@@ -4,6 +4,7 @@ from __future__ import division
 
 from math import pi
 from math import fabs
+from random import sample
 
 from compas.geometry.basic import subtract_vectors
 from compas.geometry.basic import cross_vectors
@@ -21,7 +22,7 @@ from compas.geometry.distance import closest_point_on_segment_xy
 from compas.geometry.size import area_triangle
 
 from compas.geometry.angles import angle_vectors
-from compas.geometry.average import center_of_mass_polygon
+from compas.geometry.average import centroid_polygon
 
 
 __all__ = [
@@ -45,6 +46,7 @@ __all__ = [
     'is_point_in_convex_polygon_xy',
     'is_point_in_circle',
     'is_point_in_circle_xy',
+    'is_polygon_in_polygon_xy',
     'is_intersection_line_line',
     'is_intersection_line_line_xy',
     'is_intersection_segment_segment',
@@ -200,11 +202,13 @@ def is_coplanar(points, tol=0.01):
     # len(points) > 4
     # compare length of cross product vector to tolerance
 
-    u = subtract_vectors(points[1], points[0])
-    v = subtract_vectors(points[2], points[1])
+    a, b, c = sample(points, 3)
+
+    u = subtract_vectors(b, a)
+    v = subtract_vectors(c, a)
     w = cross_vectors(u, v)
 
-    for i in range(1, len(points) - 2):
+    for i in range(0, len(points) - 2):
         u = v
         v = subtract_vectors(points[i + 2], points[i + 1])
         wuv = cross_vectors(w, cross_vectors(u, v))
@@ -233,7 +237,7 @@ def is_polygon_convex(polygon):
     is_polygon_convex_xy
 
     """
-    c = center_of_mass_polygon(polygon)
+    c = centroid_polygon(polygon)
 
     for i in range(-1, len(polygon) - 1):
         p0 = polygon[i]
@@ -660,19 +664,25 @@ def is_point_in_convex_polygon_xy(point, polygon):
 def is_point_in_polygon_xy(point, polygon):
     """Determine if a point is in the interior of a polygon lying in the XY-plane.
 
-    Parameters:
-        point (sequence of float): XY(Z) coordinates of a 2D or 3D point (Z will be ignored).
-        polygon (sequence) : A sequence of XY(Z) coordinates of 2D or 3D points
-        (Z will be ignored) representing the locations of the corners of a polygon.
-        The vertices are assumed to be in order. The polygon is assumed to be closed:
-        the first and last vertex in the sequence should not be the same.
+    Parameters
+    ----------
+    point : sequence of float
+        XY(Z) coordinates of a 2D or 3D point (Z will be ignored).
+    polygon : sequence
+        A sequence of XY(Z) coordinates of 2D or 3D points (Z will be ignored) representing the locations of the corners of a polygon.
+        The vertices are assumed to be in order.
+        The polygon is assumed to be closed.
+        The first and last vertex in the sequence should not be the same.
 
-    Warning:
-        A boundary check is not yet implemented.
-        This should include a tolerance value.
+    Warning
+    -------
+    A boundary check is not yet implemented. This should include a tolerance value.
+
+    Returns
+    -------
+    bool
+        True if the point is in the polygon, False otherwise.
 
-    Returns:
-        bool: True if the point is in the polygon, False otherwise.
     """
     x, y = point[0], point[1]
     polygon = [(p[0], p[1]) for p in polygon]  # make 2D
@@ -724,6 +734,45 @@ def is_point_in_circle_xy(point, circle):
     return False
 
 
+def is_polygon_in_polygon_xy(polygon1, polygon2):
+    """Determine if a polygon is in the interior of another polygon, both lying in the XY-plane.
+
+    Parameters
+    ----------
+    polygon1 : list
+        List of XY(Z) coordinates of 2D or 3D points
+        (Z will be ignored) representing the locations of the corners of the exterior polygon.
+        The vertices are assumed to be in order. The polygon is assumed to be closed:
+        the first and last vertex in the sequence should not be the same.
+    polygon2 : list
+        List of XY(Z) coordinates of 2D or 3D points
+        (Z will be ignored) representing the locations of the corners of the interior polygon.
+        The vertices are assumed to be in order. The polygon is assumed to be closed:
+        the first and last vertex in the sequence should not be the same.
+
+    Returns
+    -------
+    bool
+        True if polygon2 is inside polygon1, False otherwise.
+
+    """
+    if is_polygon_convex_xy(polygon1) and is_polygon_convex_xy(polygon2):
+        for pt in polygon2:
+            if not is_point_in_convex_polygon_xy(pt, polygon1):
+                return False
+        return True
+    else:
+        for i in range(len(polygon1)):
+            line = [polygon1[-i], polygon1[-i - 1]]
+            for j in range(len(polygon2)):
+                line_ = [polygon2[-j], polygon2[j - 1]]
+                if is_intersection_segment_segment_xy(line, line_):
+                    return False
+        for pt in polygon2:
+            if is_point_in_polygon_xy(pt, polygon1):
+                return True
+        return False
+
 # ==============================================================================
 # intersections
 # ==============================================================================
@@ -936,12 +985,20 @@ def is_intersection_plane_plane(plane1, plane2, epsilon=1e-6):
     return True
 
 
-
-
-
 # ==============================================================================
 # Main
 # ==============================================================================
 
 if __name__ == "__main__":
-    pass
+
+    import os
+    import compas
+
+    from compas.datastructures import Mesh
+
+    mesh = Mesh.from_json(os.path.join(compas.TEMP, 'm11.json'))
+
+    xyz = mesh.get_vertices_attributes('xyz')
+    xyz = [[0.0, 0.0, 0.0], [1.0, 0.0, 0.0], [1.0, 1.0, 0.0], [0.0, 1.0, 0.0], [3.0, 1.0, 0.5]]
+
+    print(is_coplanar(xyz))
