@@ -44,4 +44,8 @@ Fortran
 
 """
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 __all__ = []
